import { Observable } from 'rxjs';
import { INgSurvey, IElementsMap, IElementsMaps, IOptionAnswersMap, IOptionAnswersMaps, IPageMap, NgSurveyState } from '../models';
import { NgSurveyStore } from '../store/ng-survey.store';
export declare class NgSurveysService {
    private _ngSurveyStore;
    constructor(_ngSurveyStore: NgSurveyStore);
    /**
     * Listen to the latest state changes in the stream.
     * @return This method returns changes
     * that occur to all of the survey state.
     */
    getNgSurveyState(): Observable<NgSurveyState>;
    /**
     * Listen to the latest survey state changes in the stream.
     * @return This method returns changes
     * that occur to the survey state.
     */
    getSurveyChanges(): Observable<INgSurvey>;
    /**
     * Listen to the latest pages state changes in the stream.
     * @return This method returns changes
     * that occur to the pages state.
     */
    getPagesChanges(): Observable<IPageMap>;
    /**
     * Listen to the latest element state changes in the stream.
     * @return This method returns changes
     * that occur to the elements state.
     */
    getElementsChanges(): Observable<IElementsMaps>;
    /**
     * Listen to the latest element state changes of a page in the stream.
     * @param pageId to retrieve elements of a specific page
     * @return This method returns changes
     * that occur to the elements state filtered by pageId.
     */
    getElementsByPageIdChanges(pageId: string): Observable<IElementsMap>;
    /**
     * Listen to the latest option answers state changes in the stream.
     * @return This method returns changes
     * that occur to the option answers state.
     */
    getOptionAnswersChanges(): Observable<IOptionAnswersMaps>;
    /**
     * Listen to the latest option answers state changes of an element in the stream.
     * @param elementId to retrieve option answers of a specific element
     * @return This method returns changes
     * that occur to the option answers state filtered by elementId.
     */
    getOptionAnswersByElementIdChanges(elementId: string): Observable<IOptionAnswersMap>;
}
